/*
* This file contains all the necessary settings for the IQS7221E and this file 
* can be changed from the GUI or edited here
* File:   IQS7221E_init.h
* Author: Azoteq
*/ 

#ifndef IQS7221E_INIT_H
#define IQS7221E_INIT_H

/* Change the Global Device Settings */
/* Memory Map Position 0x60 - 0x6F */
#define UI_SETTINGS                              0x11
#define UI_SETTINGS_1                            0x49
#define I2C_SETTINGS                             0x00
#define OPEN_60_3                                0x00
#define HA_REPORT_0                              0x05
#define HA_REPORT_1                              0x00
#define NP_REPORT_0                              0x28
#define NP_REPORT_1                              0x00
#define LP_REPORT_0                              0xC8
#define LP_REPORT_1                              0x00
#define ULP_REPORT_0                             0xF4
#define ULP_REPORT_1                             0x01
#define ULP_TIMEOUT_0                            0x30
#define ULP_TIMEOUT_1                            0x75
#define EVENTMASK                                0x1D
#define OPEN_0                                   0x00
#define QUADRATURE_DELAY_0                       0x64
#define QUADRATURE_DELAY_1                       0x00
#define QUADRATURE_MODE_0                        0x02
#define QUADRATURE_MODE_1                        0x00
#define WDT_TIMEOUT_0                            0xE8
#define WDT_TIMEOUT_1                            0x03
#define PS_DELAY_0                               0x80
#define PS_DELAY_1                               0x02
#define IR_ADD_0                                 0x00
#define IR_ADD_1                                 0x00
#define IR_DATA_0                                0x00
#define IR_DATA_1                                0x00
#define IW_ADD_0                                 0x00
#define IW_ADD_1                                 0x00
#define IW_DATA_0                                0x00
#define IW_DATA_1                                0x00

/* Change the Hall UI Settings */
/* Memory Map Position 0x70 - 0x7A */
#define WHEEL_TO_MAGNET_ANGLE_0                  0x03
#define WHEEL_TO_MAGNET_ANGLE_1                  0x53
#define WHEEL_TO_MAGNET_ANGLE_2                  0x00
#define WHEEL_TO_MAGNET_ANGLE_3                  0x00
#define FILTER_SWITCH_DELAY_0                    0xE8
#define FILTER_SWITCH_DELAY_1                    0x03
#define OPEN_1                                   0x08
#define OPEN_2                                   0x00
#define INTERVAL_HYSTERESIS_0                    0xFA
#define INTERVAL_HYSTERESIS_1                    0x00
#define NUMBER_INTERVALS_0                       0x18
#define NUMBER_INTERVALS_1                       0x00
#define HIGH_ACCURACY_TIMEOUT_0                  0x2C
#define HIGH_ACCURACY_TIMEOUT_1                  0x01
#define STATIONARY_TIMEOUT_0                     0x88
#define STATIONARY_TIMEOUT_1                     0x13
#define SLOW_FILTER_BETA                         0x05
#define FAST_FILTER_BETA                         0x02
#define LP_FILTER_BETA                           0x01
#define AUTO_ZERO_BETA                           0x01
#define GENERAL_HALL_SETTINGS_0                  0x06
#define GENERAL_HALL_SETTINGS_1                  0x01

/* Change the Hall Plate Settings */
/* Memory Map Position 0x80 - 0x86 */
#define PROX_A_ATI_0                             0xE2
#define PROX_A_ATI_1                             0x05
#define PROX_B_ATI_0                             0xE2
#define PROX_B_ATI_1                             0x05
#define A0_HALLPLATE_BIAS                        0xDB
#define B1_HALLPLATE_BIAS                        0xDB
#define A1_HALLPLATE_BIAS                        0xDB
#define B0_HALLPLATE_BIAS                        0xDB
#define A0_LINEAR_OFFSET                         0x6F
#define B1_LINEAR_OFFSET                         0x71
#define A1_LINEAR_OFFSET                         0x73
#define B0_LINEAR_OFFSET                         0x6E
#define CTRL0_SETTINGS_0                         0x1D
#define CTRL0_SETTINGS_1                         0x92
#define CTRL1_SETTINGS_0                         0x04

/* Change the Freewheel Settings */
/* Memory Map Position 0x90 - 0x9B */
#define FILTER_BETAS_0                           0x04
#define FILTER_BETAS_1                           0x02
#define FREEWHEEL_FRICTION_0                     0x14
#define FREEWHEEL_FRICTION_1                     0x00
#define FREEWHEEL_DAMPING_0                      0x88
#define FREEWHEEL_DAMPING_1                      0x13
#define FREEWHEEL_INERTIA_0                      0xFF
#define FREEWHEEL_INERTIA_1                      0x00
#define FREEWHEEL_MIN_START_0                    0x28
#define FREEWHEEL_MIN_START_1                    0x00
#define FREEWHEEL_STOP_0                         0x14
#define FREEWHEEL_STOP_1                         0x00
#define FREEWHEEL_FILTERSPEED_0_0                0x00
#define FREEWHEEL_FILTERSPEED_0_1                0x80
#define FREEWHEEL_FILTERSPEED_1_0                0x00
#define FREEWHEEL_FILTERSPEED_1_1                0x00
#define STOP_THR                                 0x14
#define FORWARD_THR                              0x14
#define REVERSE_THR                              0x14
#define OPEN_90_19                               0x00
#define MOVEMENT_THRESHOLD_STOP_0                0xAA
#define MOVEMENT_THRESHOLD_STOP_1                0x0A
#define STATIONARY_DETECT_SPEED_0                0x28
#define STATIONARY_DETECT_SPEED_1                0x00

/* Change the Hall ATI Settings */
/* Memory Map Position 0xA0 - 0xA2 */
#define MINIMUM_TARGET_0                         0xC8
#define MINIMUM_TARGET_1                         0x00
#define MAXIMUM_TARGET_0                         0x2C
#define MAXIMUM_TARGET_1                         0x01
#define ATI_FRAC                                 0x03
#define RE_BLOCK                                 0x02

/* Change the Button Settings */
/* Memory Map Position 0xB0 - 0xB7 */
#define BUTTON_PROX_TIMEOUT_0                    0xA0
#define BUTTON_PROX_TIMEOUT_1                    0x0F
#define BUTTON_TOUCH_TIMEOUT_0                   0x40
#define BUTTON_TOUCH_TIMEOUT_1                   0x9C
#define BUTTON_DORMANCY_TIMEOUT_0                0xA0
#define BUTTON_DORMANCY_TIMEOUT_1                0x0F
#define ATI_TIMEOUT_0                            0xE8
#define ATI_TIMEOUT_1                            0x03
#define FILTER_COUNT_BETA_NP                     0x02
#define FILTER_COUNT_BETA_LP                     0x01
#define FILTER_LTA_BETA_NP                       0x08
#define FILTER_LTA_BETA_LP                       0x07
#define FILTER_LTA_BETA_FAST_NP                  0x04
#define FILTER_LTA_BETA_FAST_LP                  0x03
#define FILTER_LTA_BETA_FAST_BAND                0x05
#define RESEED_ATI_BAND                          0x10

/* Change the Button Sensor Settings */
/* Memory Map Position 0xC0 - 0xC7 */
#define GENERAL_SENSOR_SETTINGS                  0x05
#define SENSOR_CONV_FREQ_FRAC                    0x7F
#define SENSOR_CONV_FREQ_PERIOD                  0x10
#define GENERAL_SENSOR_SETTINGS2                 0x1A
#define SENSOR_TX_SEL0                           0x01
#define SENSOR_TX_SEL1                           0x00
#define SENSOR_GENERALS                          0x15
#define SENSOR_CTRL0                             0xCF
#define SENSOR_ATI_BASE0                         0x64
#define SENSOR_ATI_BASE1                         0x00
#define SENSOR_ATI_TARGET0                       0xF4
#define SENSOR_ATI_TARGET1                       0x01
#define SENSOR_COARSE                            0xE8
#define SENSOR_FINE                              0xA0
#define SENSOR_COMPENSATION                      0xCC
#define SENSOR_COMPENSATION_DIVIDER              0x2D

/* Change the Button Threshold Settings */
/* Memory Map Position 0xD0 - 0xD1 */
#define PROX_THRESHOLD                           0x14
#define PROX_DEBOUNCE                            0x12
#define TOUCH_THRESHOLD                          0x14
#define TOUCH_HYSTERESIS                         0x34

/* Change the I2C Settings */
/* Memory Map Position 0xE0 - 0xE0 */
#define I2CRDYTO_0                               0xF4
#define I2CRDYTO_1                               0x01

#endif	/* IQS7221E_INIT_H */