/******************************************************************************
 *                                                                            *
 *                                                                            *
 *                                Copyright by                                *
 *                                                                            *
 *                              Azoteq (Pty) Ltd                              *
 *                          Republic of South Africa                          *
 *                                                                            *
 *                           Tel: +27(0)21 863 0033                           *
 *                           E-mail: info@azoteq.com                          *
 *                                                                            *
 * ========================================================================== *
 * @file        iqs7221e_addresses.h                                          *
 * @brief       IQS7221E - Registers & Memory Map                             *
 * @author      Azoteq PTY Ltd                                                *
 * @version     v1.2                                                          *
 * @date        2023                                                          *
 * @see         Refer to IQS7221E datasheet for more information,             *
 *              available here: https://www.azoteq.com/design/datasheets/     *
 ******************************************************************************/

#ifndef __IQS7221E_ADDRESSES_H
#define __IQS7221E_ADDRESSES_H

/* Device Information - Read Only */

/* All Banks: 0x00 - 0x26 */
#define IQS7221E_MM_PROD_NUM                0x00
#define IQS7221E_MM_MAJOR_VERSION_NUM       0x01
#define IQS7221E_MM_MINOR_VERSION_NUM       0x02

/* DATA: 0x10 - 0x14 */
#define IQS7221E_MM_SYSTEM_FLAGS            0x10
#define IQS7221E_MM_GLOBAL_EVENTS           0x11
#define IQS7221E_MM_HALL_UI_FLAGS           0x12
#define IQS7221E_MM_TOUCH_EVENT_STATES      0x13
#define IQS7221E_MM_FREEWHEEL_UI_FLAGS      0x14

/* HALL UI DATA 0: 0x20 - 0x2E */
#define IQS7221E_MM_HALL_INTERVAL           0x20

/* CHANNEL LTA: 0x40 - 0x4F */
#define IQS7221E_MM_CHANNEL_COUNTS         	0x40

/* FREEWHEEL DATA: 0x50 - 0x56 */
#define IQS7221E_MM_RELATIVE_SPEED          0x53

/* FLAGS AND DATA: 0x60 - 0x6F */
#define IQS7221E_MM_SYSTEM_SETTINGS         0x60

/* HALL UI SETTINGS: 0x70 - 0x7A */
#define IQS7221E_MM_WHEEL_T_MAGNET_ANGLE    0x70
#define IQS7221E_MM_HALL_UI_SETTINGS        0x7A

/* HALL PLATE SETTINGS: 0x80 - 0x86 */
#define IQS7221E_MM_HP_FINE_COURSE_MULTI    0x80

/* FREEWHEEL SETTINGS: 0x90 - 0x98 */
#define IQS7221E_MM_FREEWHEEL_FILTER_BETA   0x90

/* HALL ATI SETTINGS: 0xA0 - 0xA2 */
#define IQS7221E_MM_TARGET_MIN              0xA0

/* BUTTON SETTINGS: 0xB0 - 0xB6*/
#define IQS7221E_MM_BUTTON_PROX_TIMEOUT     0xB0

/* BUTTON SENSOR SETTINGS: 0xC0 - 0xC7 */
#define IQS7221E_MM_BUTTON_SENSOR_CONTROL_0 0xC0

/* BUTTON THRESHOLD SETTINGS: 0xD0 - 0xD1 */
#define IQS7221E_MM_BUTTON_PROX_THRESHOLD   0xD0

/* I2C SETTINGS: 0xE0 */
#define IQS7221E_MM_I2C_TRANS_TIMEOUT       0xE0


#endif /* __IQS7221E_ADDRESSES_H */
